@@ -56,7 +56,7 @@
 enum {
   ARG_0,
   ARG_HANDLE_SIZE,
-  ARG_QUANTUM,
+  ARG_QUANTUM
 };
 
 static void    e_paned_class_init (EPanedClass  *klass);
@@ -134,7 +134,9 @@ e_paned_class_init (EPanedClass *klass)
   widget_class->map = e_paned_map;
   widget_class->unmap = e_paned_unmap;
   widget_class->unrealize = e_paned_unrealize;
+#ifndef NO_WARNINGS
 #warning removed expose
+#endif
 #if 0
   widget_class->expose_event = e_paned_expose;
 #endif
@@ -365,7 +367,9 @@ e_paned_unrealize (GtkWidget *widget)
     (* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
 }
 
+#ifndef NO_WARNINGS
 #warning FIXME: badly broken
+#endif
 #if 0
 static gint
 e_paned_expose (GtkWidget      *widget,
