@@ -1,13 +1,35 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* 
+ * e-table-group-leaf.h
+ * Copyright 2000, 2001, Ximian, Inc.
+ *
+ * Authors:
+ *   Chris Lahey <clahey@ximian.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ */
+
 #ifndef _E_TABLE_GROUP_LEAF_H_
 #define _E_TABLE_GROUP_LEAF_H_
 
-#include <libgnomeui/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas.h>
 #include <gal/e-table/e-table-group.h>
 #include <gal/e-table/e-table-subset.h>
 #include <gal/e-table/e-table-item.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_TABLE_GROUP_LEAF_TYPE        (e_table_group_leaf_get_type ())
 #define E_TABLE_GROUP_LEAF(o)          (GTK_CHECK_CAST ((o), E_TABLE_GROUP_LEAF_TYPE, ETableGroupLeaf))
@@ -36,8 +58,17 @@ typedef struct {
 	guint horizontal_draw_grid : 1;
 	guint vertical_draw_grid : 1;
 	guint draw_focus : 1;
+	guint uniform_row_height : 1;
 	ECursorMode cursor_mode;
 
+	int etgl_cursor_change_id;
+	int etgl_cursor_activated_id;
+	int etgl_double_click_id;
+	int etgl_right_click_id;
+	int etgl_click_id;
+	int etgl_key_press_id;
+	int etgl_start_drag_id;
+
 	ESelectionModel *selection_model;
 } ETableGroupLeaf;
 
@@ -53,7 +84,7 @@ ETableGroup *e_table_group_leaf_new       (GnomeCanvasGroup *parent,
 GtkType      e_table_group_leaf_get_type  (void);
 
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_TABLE_GROUP_LEAF_H_ */
 
