@@ -43,7 +43,7 @@ enum {
 	POP,
 	LAST_SIGNAL
 };
-static gint gtk_combo_stack_signals [LAST_SIGNAL] = { 0, };
+static guint gtk_combo_stack_signals [LAST_SIGNAL] = { 0, };
 
 static void
 gtk_combo_stack_destroy (GtkObject *object)
@@ -150,7 +150,7 @@ list_select_cb (GtkList *list, GtkWidget *child, gpointer data)
 
 	for (ptr = items; ptr != NULL ; i++ ) {
 		gtk_widget_set_state (GTK_WIDGET (ptr->data),
-			GTK_STATE_SELECTED);
+				      GTK_STATE_SELECTED);
 		ptr = (ptr->data != child) ? ptr->next : NULL;
 	}
 	g_list_free (items);
